package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.classfile.ConstantUtf8;
import org.apache.bcel.classfile.ElementValue;
import org.apache.bcel.classfile.EnumElementValue;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/EnumElementValueGen.class */
public class EnumElementValueGen extends ElementValueGen {
    private final int typeIdx;
    private final int valueIdx;

    public EnumElementValueGen(EnumElementValue value, ConstantPoolGen cpool, boolean copyPoolEntries) {
        super(ElementValueGen.ENUM_CONSTANT, cpool);
        if (copyPoolEntries) {
            this.typeIdx = cpool.addUtf8(value.getEnumTypeString());
            this.valueIdx = cpool.addUtf8(value.getEnumValueString());
        } else {
            this.typeIdx = value.getTypeIndex();
            this.valueIdx = value.getValueIndex();
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public EnumElementValueGen(int typeIdx, int valueIdx, ConstantPoolGen cpool) {
        super(ElementValueGen.ENUM_CONSTANT, cpool);
        if (super.getElementValueType() != 101) {
            throw new IllegalArgumentException("Only element values of type enum can be built with this ctor - type specified: " + super.getElementValueType());
        }
        this.typeIdx = typeIdx;
        this.valueIdx = valueIdx;
    }

    public EnumElementValueGen(ObjectType t, String value, ConstantPoolGen cpool) {
        super(ElementValueGen.ENUM_CONSTANT, cpool);
        this.typeIdx = cpool.addUtf8(t.getSignature());
        this.valueIdx = cpool.addUtf8(value);
    }

    @Override // org.apache.bcel.generic.ElementValueGen
    public void dump(DataOutputStream dos) throws IOException {
        dos.writeByte(super.getElementValueType());
        dos.writeShort(this.typeIdx);
        dos.writeShort(this.valueIdx);
    }

    @Override // org.apache.bcel.generic.ElementValueGen
    public ElementValue getElementValue() {
        System.err.println("Duplicating value: " + getEnumTypeString() + ":" + getEnumValueString());
        return new EnumElementValue(super.getElementValueType(), this.typeIdx, this.valueIdx, getConstantPool().getConstantPool());
    }

    public String getEnumTypeString() {
        return getConstantPool().getConstant(this.typeIdx).getBytes();
    }

    public String getEnumValueString() {
        return getConstantPool().getConstant(this.valueIdx).getBytes();
    }

    public int getTypeIndex() {
        return this.typeIdx;
    }

    public int getValueIndex() {
        return this.valueIdx;
    }

    @Override // org.apache.bcel.generic.ElementValueGen
    public String stringifyValue() {
        ConstantUtf8 cu8 = getConstantPool().getConstant(this.valueIdx);
        return cu8.getBytes();
    }
}
